Save the full corpus including embeddings as a compressed RDS file.
Examples
corpus <- sm_example_corpus(n_works = 10)
path <- tempfile(fileext = ".rds")
sm_export_rds(corpus, path)
#> ✔ Corpus saved to /tmp/RtmpIQMgiF/file2370169388bd.rds
Save the full corpus including embeddings as a compressed RDS file.
corpus <- sm_example_corpus(n_works = 10)
path <- tempfile(fileext = ".rds")
sm_export_rds(corpus, path)
#> ✔ Corpus saved to /tmp/RtmpIQMgiF/file2370169388bd.rds