Returns a summary tibble of screening decisions by stage, showing the count of included, excluded, and uncertain works at each stage.
Usage
sm_screen_summary(corpus, call = rlang::caller_env())Returns a summary tibble of screening decisions by stage, showing the count of included, excluded, and uncertain works at each stage.
sm_screen_summary(corpus, call = rlang::caller_env())